@@ -25,7 +25,7 @@ from typedb.api.concept.thing.thing import Thing, RemoteThing
 
 if TYPE_CHECKING:
     from typedb.api.concept.type.entity_type import EntityType
-    from typedb.api.transaction import TypeDBTransaction
+    from typedb.api.connection.transaction import TypeDBTransaction
 
 
 class Entity(Thing, ABC):
